@@ -79,7 +79,7 @@ def find_themes():
         for theme in os.listdir(dir):
             yield theme
 
-THEME_CHOICES = ((t,t) for t in find_themes())
+THEME_CHOICES = ((t,t) for t in set(find_themes()))
 
 class SliderPlugin(CMSPlugin):
     title = models.CharField('Titulo', max_length=255, null=True, blank=True)
